@@ -8,13 +8,13 @@ require v5.10.0;
 
 use POSIX::RT::Clock;
 use Time::HiRes;
-use Data::Dumper;
+use HTTP::Tiny;
 
 use base qw(Exporter);
 
 BEGIN {
     @Time::TAI::Simple::EXPORT = qw(tai tai10 tai35);
-    $Time::TAI::Simple::VERSION = '1.10';
+    $Time::TAI::Simple::VERSION = '1.11';
 }
 
 our @LEAPSECOND_UNIX_PATHNAME_LIST = (
@@ -86,7 +86,8 @@ sub new {
         dl_to   => undef
     };
     bless ($self, $class);
-    $self->{mode} = $self->opt('mode', 'tai10');
+    $self->{http_or} = HTTP::Tiny->new(max_redirect => 15);
+    $self->{mode}    = $self->opt('mode', 'tai10');
     $self->download_leapseconds() if ($self->opt('download_leapseconds', 0));
     $self->load_leapseconds() unless ($self->opt('do_not_load_leapseconds'));
     $self->calculate_base();  # also sets tm_or and potentially ls_next
@@ -179,13 +180,14 @@ sub download_leapseconds {
     push (@url_list, 'http://www.ciar.org/ttk/codecloset/leap-seconds.list');
     push (@url_list, 'http://www.ietf.org/timezones/data/leap-seconds.list');
     eval {
-        use LWP::Simple;
+        my $http_or = $self->{http_or};
+        my $leapseconds_filename = $self->_leapseconds_filename(\%opt_h);
         foreach my $url (@url_list) {
-            my $reply = getstore($url, $self->_leapseconds_filename(\%opt_h));
-            next unless (defined($reply) && $reply =~ /^2/);
+            my $reply = $http_or->mirror($url, $leapseconds_filename, {});
+            next unless (defined($reply) && $reply->{success});
             $response = 1;
             $self->{dl_fr} = $url;
-            $self->{dl_to} = $self->_leapseconds_filename(\%opt_h);
+            $self->{dl_to} = $leapseconds_filename;
             last;
         }
     };
@@ -237,7 +239,7 @@ sub _leapseconds_filename {
 
 =head1 VERSION
 
-    1.10
+    1.11
 
 =head1 SYNOPSIS
 
